@@ -10,18 +10,17 @@ except ImportError:
 # Make API calls
 # interface/epresc/SendEpresc/<specific_endpoint>
 def make_get_request(session, endpoint, params_data=None):
-    url = urljoin(session.url, '{}/{}/'.format(prescriptions_endpoint, endpoint))
+    url = f"{session.url}{prescriptions_endpoint}{endpoint}"
     return session.session.get(url, params=params_data, verify=True)
 
 
 def make_post_request(session, endpoint, json_data):
-    url = urljoin(session.url, '{}/{}/'.format(prescriptions_endpoint, endpoint))
-    print(url)
+    url = f"{session.url}{prescriptions_endpoint}{endpoint}"
     return session.session.post(url, json=json_data, verify=True)
 
 
 def make_put_request(session, endpoint, headers=None, params_data=None,
                      form_data=None, json_data=None):
-    url = urljoin(session.url, '{}/{}/'.format(prescriptions_endpoint, endpoint))
+    url = f"{session.url}{prescriptions_endpoint}{endpoint}"
     return session.session.put(url, headers=headers, params=params_data,
                                data=form_data, json=json_data, verify=True)
